package com.example.springdemo.service;

import com.example.springdemo.dao.UsersPasswordRepository;
import com.example.springdemo.dao.UsersRepository;
import com.example.springdemo.entities.Users;
import com.example.springdemo.entities.password.UsersPassword;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Optional;

@Service
public class UsersServiceImpl implements UsersService {
    @Resource
    private UsersRepository usersRepository;

    @Resource
    private UsersPasswordRepository usersPasswordRepository;

    @Override
    @Transactional(rollbackFor = Exception.class)
    //添加用户时同步添加密码
    public Users addUser(Users user, UsersPassword userPassword) {
        Users u = usersRepository.save(user);
        usersPasswordRepository.save(userPassword);
        return u;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    //删除用户时同步删除密码
    public void deleteUserById(Long userId) {
        usersRepository.deleteById(userId);
        usersPasswordRepository.deleteByUsersId(userId);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    //删除用户时同步删除密码
    public void deleteUserByName(String name) {
        Long userId;
        //如果用户存在
        if (usersRepository.findByName(name).isPresent()) {
            usersRepository.deleteByName(name);
            //获取用户ID
            userId = usersRepository.findByName(name).get().getId();
            //删除密码
            usersPasswordRepository.deleteByUsersId(userId);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    //更新用户信息
    public Users updateUser(Users user) {
        return usersRepository.save(user);
    }

    @Override
    public List<Users> findAllUsers() {
        return usersRepository.findAll();
    }

    @Override
    public Optional<Users> findById(Long userId) {
        return usersRepository.findById(userId);
    }

    @Override
    public Optional<Users> findByName(String name) {
        return usersRepository.findByName(name);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    //更新用户密码
    public int updateUserPasswordById(String password, Long userId) {
        return usersPasswordRepository.updatePassword(password, userId);
    }
}
